==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_val-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="val-ES" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+245"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>Corba en malla...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>Corba en malla</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-191"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Crea una malla a partir d'una forma...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Tesel·la la forma</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+106"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Crea una secció a partir d'una malla i un pla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Secció</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Retalla la malla amb un pla</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Retalla una malla amb un pla</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Crea</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>Tanca el filferro</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Neteja</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Cancel·la</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>S'ha seleccionat una malla incorrecta</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>No s'ha seleccionat cap punt.</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>Corba en malla</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Filferro</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>Ajusta la tolerància als vèrtexs</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>Llindar de divisió</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Aproximació d'spline</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>Tolerància de malla</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Continuity</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>Grau màxim de la corba</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Inicia</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Tessel·lació</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Formes</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Opcions de mallat</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Estàndard</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Defineix segments pels colors de les cares</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Aplica els colors de les cares a la malla</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation type="unfinished">Angular deviation:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation type="unfinished">Relative surface deviation</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Longitud màxima de l'aresta:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Precisió:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Molt gruixuda</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Gruixuda</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Moderada</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Fina</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Molt fina</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Definida per l'usuari</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Gradació de la mida de malla:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Elements per aresta:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Elements per radi de curvatura:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optimitza la superfície</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Elements de segon ordre</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Predomini de quadrilàters</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation type="unfinished">Settings</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Desviació de superfície:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation type="unfinished">Max. edge length:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+225"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Seleccioneu primer una forma per al mallat</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>No hi ha el document "%1".</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Select plane</source>
      <translation>Seleccioneu un pla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Seleccioneu un pla a partir del qual seccionat la malla</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Select plane</source>
      <translation>Seleccioneu un pla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Seleccioneu un pla al qual ajustar la malla</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Mallat</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_val-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="val-ES" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+290"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>Corba en malla...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>Corba en malla</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-235"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Crea una malla a partir d'una forma...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Tesel·la la forma</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+150"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Crea una secció a partir d'una malla i un pla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Secció</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Retalla la malla amb un pla</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Retalla una malla amb un pla</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Crea</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>Tanca el filferro</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Neteja</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Cancel·la</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>S'ha seleccionat una malla incorrecta</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>No s'ha seleccionat cap punt.</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>Corba en malla</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Filferro</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>Ajusta la tolerància als vèrtexs</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>Llindar de divisió</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Aproximació d'spline</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>Tolerància de malla</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Continuïtat</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>Grau màxim de la corba</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Inicia</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Tessel·lació</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Formes</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Opcions de mallat</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Estàndard</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Defineix segments pels colors de les cares</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Aplica els colors de les cares a la malla</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>Desviació angular:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Desviació relativa de la superfície</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Longitud màxima de l'aresta:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Precisió:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Molt gruixuda</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Gruixuda</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Moderada</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Fina</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Molt fina</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Definida per l'usuari</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Gradació de la mida de malla:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Elements per aresta:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Elements per radi de curvatura:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optimitza la superfície</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Elements de segon ordre</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Predomini de quadrilàters</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation type="unfinished">Settings</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Desviació de superfície:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation type="unfinished">Max. edge length:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+226"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Seleccioneu primer una forma per al mallat</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>No hi ha el document "%1".</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+137"/>
      <source>Select plane</source>
      <translation>Seleccioneu un pla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Seleccioneu un pla a partir del qual seccionat la malla</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Select plane</source>
      <translation>Seleccioneu un pla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Seleccioneu un pla al qual ajustar la malla</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Trim by plane</source>
      <translation>Retalla per pla</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Select the side you want to keep.</source>
      <translation>Seleccioneu la cara que voleu conservar.</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Inner</source>
      <translation>Interior</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Outer</source>
      <translation>Exterior</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Split</source>
      <translation>Divideix</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Mallat</translation>
    </message>
  </context>
</TS>
